==> distribution-6.0.0-dev.128.zip: drr/regulation/mas/rewrite/margin/reports/ExcessCollateralCollectedByCounterparty1Rule.java <==
package drr.regulation.mas.rewrite.margin.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.CollateralReportInstruction;
import drr.standards.iosco.cde.collateral.reports.ExcessCollateralCollectedByTheReportingCounterpartyRule;
import java.math.BigDecimal;
import javax.inject.Inject;


@ImplementedBy(ExcessCollateralCollectedByCounterparty1Rule.ExcessCollateralCollectedByCounterparty1RuleDefault.class)
public abstract class ExcessCollateralCollectedByCounterparty1Rule implements ReportFunction<CollateralReportInstruction, BigDecimal> {
	
	// RosettaFunction dependencies
	//
	@Inject protected ExcessCollateralCollectedByTheReportingCounterpartyRule excessCollateralCollectedByTheReportingCounterpartyRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public BigDecimal evaluate(CollateralReportInstruction input) {
		BigDecimal output = doEvaluate(input);
		
		return output;
	}

	protected abstract BigDecimal doEvaluate(CollateralReportInstruction input);

	public static class ExcessCollateralCollectedByCounterparty1RuleDefault extends ExcessCollateralCollectedByCounterparty1Rule {
		@Override
		protected BigDecimal doEvaluate(CollateralReportInstruction input) {
			BigDecimal output = null;
			return assignOutput(output, input);
		}
		
		protected BigDecimal assignOutput(BigDecimal output, CollateralReportInstruction input) {
			output = excessCollateralCollectedByTheReportingCounterpartyRule.evaluate(input);
			
			return output;
		}
	}
}

==> distribution-6.21.2.zip: drr/regulation/mas/rewrite/margin/reports/ExcessCollateralCollectedByCounterparty1Rule.java <==
package drr.regulation.mas.rewrite.margin.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.CollateralReportInstruction;
import drr.standards.iosco.cde.version3.collateral.reports.ExcessCollateralCollectedByTheReportingCounterpartyRule;
import java.math.BigDecimal;
import javax.inject.Inject;


@ImplementedBy(ExcessCollateralCollectedByCounterparty1Rule.ExcessCollateralCollectedByCounterparty1RuleDefault.class)
public abstract class ExcessCollateralCollectedByCounterparty1Rule implements ReportFunction<CollateralReportInstruction, BigDecimal> {
	
	// RosettaFunction dependencies
	//
	@Inject protected ExcessCollateralCollectedByTheReportingCounterpartyRule excessCollateralCollectedByTheReportingCounterpartyRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public BigDecimal evaluate(CollateralReportInstruction input) {
		BigDecimal output = doEvaluate(input);
		
		return output;
	}

	protected abstract BigDecimal doEvaluate(CollateralReportInstruction input);

	public static class ExcessCollateralCollectedByCounterparty1RuleDefault extends ExcessCollateralCollectedByCounterparty1Rule {
		@Override
		protected BigDecimal doEvaluate(CollateralReportInstruction input) {
			BigDecimal output = null;
			return assignOutput(output, input);
		}
		
		protected BigDecimal assignOutput(BigDecimal output, CollateralReportInstruction input) {
			output = excessCollateralCollectedByTheReportingCounterpartyRule.evaluate(input);
			
			return output;
		}
	}
}
